@@ -76,7 +76,7 @@ differential.activity.estimates.local <- function(rds.data,
       prop <- sum(tmp.wts * subset)
       N <- N * prop
       if (N < sum(subset))
-        stop("Estimated sub-population size smaller than subset.")
+        stop(sprintf("Estimated sub-population size, %f, smaller than subsets size, %f.", N, sum(subset)))
     }
     
     #This subsets setting orphaned children to be seeds
